// Ships implementation
// Copyright (C) 01.09.97 Marco Dettori and Oliver Obst
//
// $Id: ships.C,v 0.2 1998/03/16 10:48:03 oliver Exp $

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

#include <qcolor.h>

#include "ships.h"

// --- public constructor -----------------------------------------------------
// Ships :: Ships
//              char    n       : length of the ship
//
// using default color
Ships :: Ships(char n, QWidget *parent, const char *name)
        : QWidget(parent, name)
{
        TriState *tb;
        
        len = n;
        allState = TriState::EMPTY;
        buttons = new TriStates(n);
        
        for (int i=0; i < len; i++) {
                tb = new TriState(this);
                buttons->insert(i, tb);
        }        
}


// --- public constructor -----------------------------------------------------
// Ships :: Ships
//              char    n       : length of the ship
//              QColor  color   : color of the ship
Ships :: Ships(const QColor &color, char n, QWidget *parent, const char *name)
        : QWidget(parent, name)
{
        TriState *tb;
        
        len     = n;
        allState = TriState::EMPTY;
        buttons = new TriStates(n);
        
        for (int i=0; i < len; i++) {
                tb = new TriState(color, this);
                buttons->insert(i, tb);
        }

}
        
Ships :: ~Ships()
{
        delete buttons;
}

// --- protected -------------------------------------------------------------
// Ships :: resizeEvent( QResizeEvent * )
//
// resize the whole thing (horizontal) and adjust the button sizes

void Ships :: resizeEvent( QResizeEvent * )
{
        int xsize = width() / len;
        
        for (char i=0; i < len; i++ )
                buttons->at(i)->setGeometry( xsize * i, 0, xsize, height() );
}

// --- public ----------------------------------------------------------------
//
// Ships :: setAll
// set all elements to 'X'

void Ships :: setAll(TriState::State st)
{
        allState = st;
        for (int i=0; i < len; i++)
                buttons->at(i)->setState(st);
}

// --- public -----------------------------------------------------------------
//
// Ships :: getAll

TriState::State Ships :: getAll()
{
        return allState;
}


// --- public ----------------------------------------------------------------
// Ships :: setColor
//              QColor  color   : set ship color (and redraw)

void Ships :: setColor(const QColor & color)
{
        for (int i=0; i < len; i++ )
                buttons->at(i)->setBackgroundColor(color);
}

// --- public ----------------------------------------------------------------
// Ships :: length()
//              return length of ship

short Ships :: length()
{
        return len;
}
